<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Common\Respository\VirtualhostBusinessRespository;
use Common\Data\GiantAPIParamsData as GiantAPIParams;
use Backend\Model\VirtualhostModel;
use Common\Model\ProductConfigModel;
use Common\Model\RegionModel;

/**
 * | 会员管理
 * | @author: duanbin
 * | @时间: 2016年10月21日 下午3:35:10
 */
class VirtualhostController extends BackendController{
	
	/**
	 * 初始化仓储和模型
	 * @时间: 2016年10月9日 下午4:49:54
	 * @author: duanbin
	 */
	public function _initialize(){
		parent::_initialize();
		$this->model = new VirtualhostModel();
		$this->respository = new VirtualhostBusinessRespository($this->model);
	}
	
	/**
	 * 用户列表
	 * @return mixed
	 */
	public function index(){
		//表头，排序相关数据
		$th = $this->model->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $this->model->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($this->model->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $this->model->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',',array_keys($this->model->sortable));
		//获取所有的数据
		$data = $this->respository->finder($field);
		//获取统计数据
		$counter = $this->respository->counter($field);
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1 : request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),	//表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,	//真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request(),
			'counter' => $counter,
			'type' => $this->model->internalPtype
		]);
		if(IS_AJAX){
			return $this->fetch();
		}else{
			$this->display();
		}
	}

	/**
	 * 更新虚拟主机业务页面
	 * @时间: 2016年10月14日 下午2:46:47
	 * @author: duanbin
	 */
	public function update(){
		$id = request()['id'] + 0;
		$entity = $this->respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该虚拟主机业务的相关信息！');
		}
		$this->assign([
			'entity' => $entity,
			'state' => $this->model->searchable['state']['data'],
			'free_trial' => [1 => '试用',0 => '购买']
		]);
		$this->display();
	}
	
	/**
	 * 更新虚拟主机业务信息
	 * @时间: 2016年10月14日 下午5:48:44
	 * @author: duanbin
	 */
	public function store(){
		$request = request(true);
		$id = $request['id'];
		unset($request['id']);
		$data = $request;
		$res = $this->respository->update($data,$id,'id');
		if($res === false){
			$msg = $this->model->getError().'更新业务信息失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '更新业务信息成功';
			$url = U('Backend/Virtualhost/index',[],false);
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 删除虚拟主机业务
	 * @时间: 2016年10月17日 下午2:39:35
	 * @author: duanbin
	 */
	public function erase(){
		$request = request();
		$id = $request['id'];
		$ptype = !$request['type'] ? '' : $request['type'];
		$res = $this->respository->eraseVirtualhostBusiness($id,$ptype);
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除业务成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 虚拟主机业务详情页面
	 * @时间: 2016年10月27日 上午11:26:01
	 * @author: duanbin
	 */
	public function details(){
		$id = request()['id'] + 0;
		$entity = $this->respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该业务的相关信息！');
		}
		//获取业务的产品配置相关信息
		$config = (new ProductConfigModel())->getConfigByPId($entity['product_id']);
		$area_code = (new RegionModel())->getArea();
		$this->assign([
			'entity' => $entity,
			'free_trial' => [1 => '试用',0 => '购买'],
			'state' => $this->model->searchable['state']['data'],
			'id' => $id,
			'area_code' => $area_code,
			'config' => $config
		]);
		$this->display();
	}

	/**
	 * 转让虚拟主机业务
	 * @时间: 2016年10月28日 上午11:24:21
	 * @author: duanbin
	 */
	public function assignment(){
		$request = request();
		$res = $this->respository->assignment($request);
		if($res === false){
			$msg = $this->model->getError().'请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 同步虚拟主机业务
	 * @时间: 2016年10月28日 上午11:24:21
	 * @author: duanbin
	 */
	public function sync(){
		$request = request();
		$id = $request['id'];
		$ptype = !$request['type'] ? '' : $request['type'];
		//同步虚拟主机操作 因为虚拟主机有四个子类型，所以这里不需要再传入ptype参数了，同步方法内部进行了处理，会找到相应的ptype
		$res = $this->respository->VirtualhostBusinessSynchronizing($id,$ptype);
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}

	/**
	 * 批量更新同步业务信息
	 * @时间: 2016年11月1日 下午4:51:23
	 * @author: duanbin
	 */
	public function syncBatch(){
		$request = request();
		$flag = $request['flag'];
		$ptype = !$request['type'] ? GiantAPIParams::PTYPE_HOST : $request['type'];
		if($flag == "batch"){
			$res = $this->respository->syncBatchTb($flag);
		}else{
			$res = $this->respository->syncBatch($ptype,$flag);
		}
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = $res;
			/*$msg['res'] = $res;
			$msg['category'] = $this->model->internalPtype;
			$msg['count'] = count($msg['res'], 1)-count($msg['res']);*/
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 批量删除
	 * @时间: 2017年1月3日 下午2:50:31
	 * @author: duanbin
	 */
	public function batcherase(){
		$request = request();
		$res = $this->respository->batchErase($request);
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
}
