<?php
namespace Backend\Model;
use Backend\Model\BackendModel;

/**
 * 管理员数据模型
 * @author: duanbin
 * @时间: 2016年10月21日 下午3:37:24
 */
class UsersModel extends BackendModel{

	protected $trueTableName = 'agent_users';

	// 自动验证
	protected $_validate = array(array('username','require','用户名必须',0,'',3)); // 验证字段必填

	// 自动完成
	protected $_auto = array(array('register_time','time',1,'function')); // 对date字段在新增的时候写入当前时间戳

	/**
	 * 加密密码
	 * @时间: 2016年10月8日 下午4:36:29
	 * @author: duanbin
	 * @param $password
	 * @return string
	 */
	public function md5Password($password){
		return md5($password.C('APP_KEY'));
	}

	/**
	 * 添加用户
	 */
	public function addData($data){
		//对data数据进行验证
		if(!$data = $this->create($data)){
			//验证不通过返回错误
			return false;
		}else{
			// 验证通过
			$result = $this->add($data);
			return $result;
		}
	}

	/**
	 * 修改用户
	 */
	public function editData($map,$data){
		//对data数据进行验证
		if(!$data = $this->create($data)){
			//验证不通过返回错误
			return false;
		}else{
			//验证通过
			$result = $this->where(array($map))->save($data);
			return $result;
		}
	}

	/**
	 * 删除数据
	 * @param   array $map  where语句数组形式
	 * @return  bool|mixed       操作是否成功
	 */
	public function deleteData($map){
		//die('禁止删除用户');
		if($map['id'] != '1'){
			$result = $this->where($map)->delete();
			return $result;
		}else{
			return false;
		}
	}

	/**
	 * 修改管理员密码
	 * @时间: 2016年11月14日 下午3:34:21
	 * @author: duanbin
	 * @param $data
	 * @return bool
	 */
	public function updatePwd($data){
		if(empty($data['old_pwd'])){
			$this->error = '原密码不能为空哦！';
			return false;
		}
		if(empty($data['new_pwd'])){
			$this->error = '新密码不能为空哦！';
			return false;
		}
		if(empty($data['confirm_pwd'])){
			$this->error = '确认密码不能为空哦！';
			return false;
		}
		//新密码和确认密码是否一致
		if($data['new_pwd'] != $data['confirm_pwd']){
			$this->error = '新密码和确认密码不一样哦！您可能填错了一个！';
			return false;
		}
		//查看新密码是否足够安全（数字大小写字母 6-20位）
		if(!passwordIsStrong($data['new_pwd'])){
			$this->error = '新密码必须是6到20位数字、字母或特殊字符组成！';
			return false;
		}
		//判断输入的原密码是否正确
		$admin_id = session('admin')['id'];
		$current_admin = $this->find($admin_id);
		if(md5Password($data['old_pwd']) != $current_admin['password']){
			$this->error = '原密码错误！';
			return false;
		}
		//修改新密码
		$where['id'] = ['eq',$admin_id];
		$res = $this->where($where)->setField('password',md5Password($data['new_pwd']));
		if($res === false){
			$this->error = '操作失败了，在试一次吧！';
			return false;
		}else{
			return true;
		}
	}

	/**
	 * 重置管理员密码
	 * @时间: 2017年11月14日14:45:48
	 * @author: Guopeng
	 * @param $data
	 * @return bool
	 */
	public function resetPsd($data){
		if (empty($data['user_name'])){
			$this->error = '用户名不能为空哦！';
			return false;
		}
		if (empty($data['email'])){
			$this->error = '邮箱不能为空哦！';
			return false;
		}
		//判断输入的原密码是否正确
		$where["username"] = $data['user_name'];
		$current_admin = $this->where($where)->find();
		if(!$current_admin){
			$this->error = '不存在该管理员！';
			return false;
		}
		$site_config = WebSiteConfig(13);
		if ($data['email'] != $site_config['mailaddress']){
			$this->error = '邮箱填写错误！';
			return false;
		}
		$chars = "abcdefghijklmnopqrstuvwxyz0123456789";
		$password = "";
		for($i = 0;$i < 8;$i++){
			$password .= $chars[mt_rand(0,strlen($chars) - 1)];
		}
		$app_key = C("APP_KEY");
		$save["password"] = md5($password.$app_key);
		$res = $this->where($where)->save($save);
		if($res !== false){
			$member['login_name'] = $data['user_name'];
			$member['user_pass'] = $password;
			//修改新密码
			$mail_content = HTMLContentForEmail(5,'',$member);
			//发送邮件
			$res = postOffice($site_config['mailaddress'],$mail_content['subject'],$mail_content['body'],5);
			if($res["status"] == 1){
				$this->error = '密码已重置，邮件发送失败！';
			}else{
				return true;
			}
		}else{
			$this->error = '操作失败了，在试一次吧！';
			return false;
		}
	}
}
